aboutsummaryrefslogtreecommitdiffstats
path: root/calendar/gui/dialogs/task-editor.c
diff options
context:
space:
mode:
Diffstat (limited to 'calendar/gui/dialogs/task-editor.c')
-rw-r--r--calendar/gui/dialogs/task-editor.c7
1 files changed, 3 insertions, 4 deletions
diff --git a/calendar/gui/dialogs/task-editor.c b/calendar/gui/dialogs/task-editor.c
index 51495d8145..dd40c1b9df 100644
--- a/calendar/gui/dialogs/task-editor.c
+++ b/calendar/gui/dialogs/task-editor.c
@@ -42,15 +42,14 @@ typedef struct {
/* UI handler */
BonoboUIHandler *uih;
/* Calendar object we are editing; this is an internal copy and is not
* one of the read-only objects from the parent calendar.
*/
- iCalObject *ico;
+ CalComponent *comp;
/* Widgets from the Glade file */
GtkWidget *app;
-
} TaskEditorPrivate;
@@ -42,15 +42,14 @@ typedef struct {
/* UI handler */
BonoboUIHandler *uih;
- /* Calendar object we are editing; this is an internal copy and is not
- * one of the read-only objects from the parent calendar.
+ /* Calendar component we are editing; this is an internal copy and is
+ * not one of the read-only objects from the parent calendar.
*/